export class Image {
    constructor() {
        this.filter = ''; // filter based on search term
    }
    generateSrc() {
        if (this.src)
            return this.src;
        let size = '';
        if (this.width && this.height) {
            size = `${this.width}x${this.height}/`;
        }
        let filter = '';
        if (this.filter) {
            filter = `?${this.filter}`;
        }
        if (this.photo) {
            return `https://source.unsplash.com/${this.photo}/${size}`;
        }
        if (this.user) {
            return this.likes ?
                `https://source.unsplash.com/user/${this.user}/likes/${size}${filter}` :
                `https://source.unsplash.com/user/${this.user}/${size}${filter}`;
        }
        if (this.collection) {
            return `https://source.unsplash.com/collection/${this.collection}/${size}${filter}`;
        }
        return `https://source.unsplash.com/random/${size}${filter}`;
    }
    componentDidLoad() {
        if ('IntersectionObserver' in window) {
            this.io = new IntersectionObserver((data) => {
                if (data[0].isIntersecting) {
                    this.loadImage();
                    this.cleanup();
                }
            });
            this.io.observe(this.el);
        }
        else {
            this.loadImage();
        }
    }
    componentDidUnload() {
        this.cleanup();
    }
    loadImage() {
        this._src = this.generateSrc();
    }
    cleanup() {
        if (this.io) {
            this.io.disconnect();
            this.io = null;
        }
    }
    render() {
        return (h("img", { class: "o-image", src: this._src, alt: this.alt }));
    }
    static get is() { return "blaze-image"; }
    static get properties() { return {
        "_src": {
            "state": true
        },
        "alt": {
            "type": String,
            "attr": "alt"
        },
        "collection": {
            "type": String,
            "attr": "collection"
        },
        "el": {
            "elementRef": true
        },
        "filter": {
            "type": String,
            "attr": "filter"
        },
        "height": {
            "type": Number,
            "attr": "height"
        },
        "likes": {
            "type": Boolean,
            "attr": "likes"
        },
        "photo": {
            "type": String,
            "attr": "photo"
        },
        "src": {
            "type": String,
            "attr": "src"
        },
        "user": {
            "type": String,
            "attr": "user"
        },
        "width": {
            "type": Number,
            "attr": "width"
        }
    }; }
}
