export class Modal {
    constructor() {
        this.ghost = false;
        this.full = false;
        this.open = false;
        this.dismissible = false;
        this._isOpen = false;
    }
    close() {
        this._isOpen = false;
    }
    show() {
        this._isOpen = true;
    }
    isOpen() {
        return this._isOpen;
    }
    componentWillLoad() {
        this._isOpen = this.open;
    }
    dismiss() {
        if (this.dismissible)
            this.close();
    }
    render() {
        const ghostClass = this.ghost ? `o-modal--ghost` : '';
        const fullClass = this.full ? `o-modal--full` : '';
        const modalIsOpenClass = this._isOpen ? 'o-modal--visible' : '';
        return ([
            h("blaze-overlay", { "aria-hidden": true, open: this._isOpen, onClick: () => this.dismiss() }),
            h("div", { role: "dialog", class: `o-modal ${ghostClass} ${fullClass} ${modalIsOpenClass}` },
                this.dismissible &&
                    h("button", { type: "button", class: "c-button c-button--close", onClick: () => this.close() }, "\u00D7"),
                h("slot", null))
        ]);
    }
    static get is() { return "blaze-modal"; }
    static get properties() { return {
        "_isOpen": {
            "state": true
        },
        "close": {
            "method": true
        },
        "dismissible": {
            "type": Boolean,
            "attr": "dismissible"
        },
        "elem": {
            "elementRef": true
        },
        "full": {
            "type": Boolean,
            "attr": "full"
        },
        "ghost": {
            "type": Boolean,
            "attr": "ghost"
        },
        "isOpen": {
            "method": true
        },
        "open": {
            "type": Boolean,
            "attr": "open"
        },
        "show": {
            "method": true
        }
    }; }
}
