/*! Built with http://stenciljs.com */
import { h } from './blaze-atoms.core.js';
var Image = /** @class */ (function () {
    function Image() {
        this.filter = ''; // filter based on search term
    }
    Image.prototype.generateSrc = function () {
        if (this.src)
            return this.src;
        var size = '';
        if (this.width && this.height) {
            size = this.width + "x" + this.height + "/";
        }
        var filter = '';
        if (this.filter) {
            filter = "?" + this.filter;
        }
        if (this.photo) {
            return "https://source.unsplash.com/" + this.photo + "/" + size;
        }
        if (this.user) {
            return this.likes ?
                "https://source.unsplash.com/user/" + this.user + "/likes/" + size + filter :
                "https://source.unsplash.com/user/" + this.user + "/" + size + filter;
        }
        if (this.collection) {
            return "https://source.unsplash.com/collection/" + this.collection + "/" + size + filter;
        }
        return "https://source.unsplash.com/random/" + size + filter;
    };
    Image.prototype.componentDidLoad = function () {
        var _this = this;
        if ('IntersectionObserver' in window) {
            this.io = new IntersectionObserver(function (data) {
                if (data[0].isIntersecting) {
                    _this.loadImage();
                    _this.cleanup();
                }
            });
            this.io.observe(this.el);
        }
        else {
            this.loadImage();
        }
    };
    Image.prototype.componentDidUnload = function () {
        this.cleanup();
    };
    Image.prototype.loadImage = function () {
        this._src = this.generateSrc();
    };
    Image.prototype.cleanup = function () {
        if (this.io) {
            this.io.disconnect();
            this.io = null;
        }
    };
    Image.prototype.render = function () {
        return (h("img", { class: "o-image", src: this._src, alt: this.alt }));
    };
    Object.defineProperty(Image, "is", {
        get: function () { return "blaze-image"; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Image, "properties", {
        get: function () {
            return {
                "_src": {
                    "state": true
                },
                "alt": {
                    "type": String,
                    "attr": "alt"
                },
                "collection": {
                    "type": String,
                    "attr": "collection"
                },
                "el": {
                    "elementRef": true
                },
                "filter": {
                    "type": String,
                    "attr": "filter"
                },
                "height": {
                    "type": Number,
                    "attr": "height"
                },
                "likes": {
                    "type": Boolean,
                    "attr": "likes"
                },
                "photo": {
                    "type": String,
                    "attr": "photo"
                },
                "src": {
                    "type": String,
                    "attr": "src"
                },
                "user": {
                    "type": String,
                    "attr": "user"
                },
                "width": {
                    "type": Number,
                    "attr": "width"
                }
            };
        },
        enumerable: true,
        configurable: true
    });
    return Image;
}());
export { Image as BlazeImage };
